@@ -1,23 +1,8 @@
-// -*- indent-tabs-mode:nil -*-
-// vim: set ts=4 sts=4 sw=4 et:
 /* This file is part of the KDE project
-   Copyright (C) 2000 David Faure <faure@kde.org>
-   Copyright (C) 2002-2003 Alexander Kellett <lypanov@kde.org>
+   SPDX-FileCopyrightText: 2000 David Faure <faure@kde.org>
+   SPDX-FileCopyrightText: 2002-2003 Alexander Kellett <lypanov@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License version 2 or at your option version 3 as published by
-   the Free Software Foundation.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only
 */
 
 #include "commands.h"
